@@ -1,7 +1,5 @@
-import functools
-from time import time
-
-from spatialtis.config import Config, console
+from spatialtis.config import CONFIG
+from spatialtis.console import console
 
 
 def pretty_time(t):
@@ -23,7 +21,7 @@ def pretty_time(t):
 
 def log_print(text, custom=False, color="green", verbose=None):
     if verbose is None:
-        verbose = Config.verbose
+        verbose = CONFIG.VERBOSE
 
     if verbose:
         if not custom:
